@testset "Conjugacy" begin
  a = fmpz[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
           1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
           0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0,
           0, -9604, -7056, -12076, -2392, -2253, 952, 46, -16, 0, 0, 0, 0, 0,
           0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -4900, -140]

  b = fmpz[-4645900, -49391, -3848404, -16744, -15771, 6664, 17066, 470484,
           33488, 3779643, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1,
           0, -2, 0, -26, 0, -8, 0, 1, 0, 0, 1, 0, 9, -55750240, -592692,
           -46180848, -200928, -189252, 79969, 204792, 5645808, 396956,
           45355576, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -10, 0, -8, 0, 0, 0, 0, 1,
           0, 8, 101541620, 1079546, 84115116, 365984, 344709, -145656,
           -373022, -10283436, -692768, -82611077, -4, 0, 0, 0, 0, 0, 0, 0, 0,
           1, -18583040, -197564, -15393616, -66976, -63084, 26656, 68264,
           1881936, 129052, 15118432]

  A = matrix(ZZ, 10, 10, a)
  B = matrix(ZZ, 10, 10, b)

  fl, C = Hecke.is_GLZ_conjugate(A, B)
  @test fl
  @test C * A == B * C

  A = matrix(QQ, 10, 10, a)
  B = matrix(QQ, 10, 10, b)

  fl, C = Hecke.is_GLZ_conjugate(A, B)
  _C = map_entries(QQ, C)
  @test fl
  @test _C * A == B * _C

  A = fmpq(1, 10) * A
  B = fmpq(1, 10) * B
  fl, C = Hecke.is_GLZ_conjugate(A, B)
  _C = map_entries(QQ, C)
  @test fl
  @test _C * A == B * _C

  fl, _ = Hecke.is_GLZ_conjugate(QQ[1 2; 3 4], QQ[1 2 3; 4 5 6; 7 8 9])
  @test !fl

  R = ResidueRing(FlintZZ, fmpz(7))
  x, y = R(6), R(6)
  q, r = divrem(x, y)
  @test y * q + r == x
  @test iszero(r)

  fl, = Hecke.isGLZ_conjugate(ZZ[0 1; 0 0], ZZ[0 2; 0 0])
  @test !fl

  I = matrix(ZZ, 8, 8, [-21 12 17 -3 -3 15 10 -8;
                       -6 3 5 -1 -4 5 4 -2;
                       -36 18 29 -5 7 25 16 -16;
                       -72 36 58 -11 13 52 33 -33;
                       0 0 0 0 -9 3 2 0;
                       0 0 0 0 -21 0 5 4;
                       0 0 0 0 -9 0 2 2;
                       0 0 0 0 -36 0 8 7])
  J = matrix(ZZ, 8, 8, [0 3 0 -1 0 0 0 0;
                        -3 0 1 0 0 0 0 0;
                        0 0 0 1 0 0 0 0;
                        -9 0 2 0 0 0 0 0;
                        0 0 0 0 -63 48 51 -13;
                        0 0 0 0 -84 63 68 -17;
                        0 0 0 0 -36 27 29 -7;
                        0 0 0 0 -144 108 116 -29])
  for k in 1:10
    fl, T = is_GLZ_conjugate(I, J)
    @test fl
    @test T * I == J * T && isone(abs(det(T)))
  end

  # Example from #834
  M = matrix(ZZ, 6, 6, [-15, 8, 0, 0, -30, 26,
                        -30, 15, 0, 0, -30, 30,
                        0, 0, -15, 8, 0, -4,
                        0, 0, -30, 15, -30, 15,
                        0, 0, 0, 0, -45, 34,
                        0, 0, 0, 0, -60, 45 ])
  N = matrix(ZZ, 6, 6, [-15, 8, 0, 0, 0, -4,
                        -30, 15, 0, 0, -30, 15,
                        0, 0, -15, 8, -30, 26,
                        0, 0, -30, 15, -30, 30,
                        0, 0, 0, 0, -45, 34,
                        0, 0, 0, 0, -60, 45 ])

  for i in 1:5
    fl, T = is_GLZ_conjugate(M, N)
    @test fl
    @test T * M == N * T && isone(abs(det(T)))
  end
end
